@@ -1,5 +1,10 @@
 var NAVTREEINDEX7 =
 {
+"group__pw__session__manager.html#ga9ce6b085d6110a166e03135e3977c7f2":[10,7,4,133],
+"group__pw__session__manager.html#ga9e7a7a0f7a48b2f6afc5b34cd488695a":[10,7,4,112],
+"group__pw__session__manager.html#ga9ea9d15f9c2b54a69cd4b27f5f300b99":[10,7,4,42],
+"group__pw__session__manager.html#ga9f380188172b465eb8178eace5aaf02b":[10,7,4,75],
+"group__pw__session__manager.html#gaa01cdd7877f44f5e3cea92a8e22480ab":[10,7,4,84],
 "group__pw__session__manager.html#gaa17ffb9525d1063cdff54c7dcc5cda2d":[10,7,4,106],
 "group__pw__session__manager.html#gaa402cd6473e92b77d7f66d42dba6720f":[10,7,4,86],
 "group__pw__session__manager.html#gaa50cf4a5a59e55e6a003e21cc6376996":[10,7,4,44],
@@ -149,13 +154,13 @@ var NAVTREEINDEX7 =
 "group__pw__type.html#gga06fc87d81c62e9abb8790b6e5713c55ba3b264f61faadc9037f84e239b177ff0b":[10,4,15,5,0],
 "group__pw__utils.html":[10,6,8],
 "group__pw__utils.html#ga40eebfe720dbba23dbc86347dd95ba0b":[10,6,8,2],
-"group__pw__utils.html#ga47fc8395e1484903507ade1668582bf8":[10,6,8,7],
 "group__pw__utils.html#ga80e0ca15ccef3f20ef9524a26d8c2b45":[10,6,8,5],
 "group__pw__utils.html#ga86777dfdd21dbb21a2c74470aad019a4":[10,6,8,3],
 "group__pw__utils.html#ga8869815cdd42998571019730afd248ff":[10,6,8,0],
 "group__pw__utils.html#ga8927bee5a1c2d50bf44dffc697b24840":[10,6,8,1],
 "group__pw__utils.html#ga9349b2873f42849a409d3526fd874ecc":[10,6,8,8],
 "group__pw__utils.html#gab7c0e5ea4acd296a58642198133565c9":[10,6,8,6],
+"group__pw__utils.html#gac9f252f07455653aebd285fc9e05feee":[10,6,8,7],
 "group__pw__utils.html#gacdc181bb9d9a0be73f19ad2745630399":[10,6,8,4],
 "group__pw__work__queue.html":[10,5,16],
 "group__pw__work__queue.html#ga31cc6b38eda61a244c7d3fd9024a74db":[10,5,16,5],
@@ -244,10 +249,5 @@ var NAVTREEINDEX7 =
 "group__spa__ansi.html#ga5107dd7b42a3abdcd2cbf1623f5a76af":[10,8,8,0,30],
 "group__spa__ansi.html#ga54d15ab61e76cc597c18301ff384435e":[10,8,8,0,1],
 "group__spa__ansi.html#ga5d126113edfe9df70eb7f68a6f874c85":[10,8,8,0,31],
-"group__spa__ansi.html#ga5dafdd57666d36a3a23172b309e5e2d8":[10,8,8,0,42],
-"group__spa__ansi.html#ga678d0b293b16e0d6a1fe0acef4915d58":[10,8,8,0,38],
-"group__spa__ansi.html#ga67b64705e0973206f62671580235ad91":[10,8,8,0,36],
-"group__spa__ansi.html#ga7e7da142af610c73f650312677383d99":[10,8,8,0,13],
-"group__spa__ansi.html#ga81bfa95fac68a133fd545e7fa4e9d1d1":[10,8,8,0,5],
-"group__spa__ansi.html#ga82142b091ace82f6742527d72cb3a9e4":[10,8,8,0,52]
+"group__spa__ansi.html#ga5dafdd57666d36a3a23172b309e5e2d8":[10,8,8,0,42]
 };
